URL = "http://plaato.blynk.cc/{auth_token}/get"

# Units
UNIT_TEMP_CELSIUS = "°C"
UNIT_TEMP_FAHRENHEIT = "°F"
UNIT_PERCENTAGE = "%"
UNIT_OZ = "oz"
UNIT_LITRE = "l"
UNIT_BUBBLES_PER_MINUTE = "bpm"

METRIC = "1"

# Webhook attributes
ATTR_DEVICE_ID = "device_id"
ATTR_DEVICE_NAME = "device_name"
ATTR_TEMP_UNIT = "temp_unit"
ATTR_VOLUME_UNIT = "volume_unit"
ATTR_BPM = "bpm"
ATTR_TEMP = "temp"
ATTR_SG = "sg"
ATTR_OG = "og"
ATTR_BUBBLES = "bubbles"
ATTR_ABV = "abv"
ATTR_CO2_VOLUME = "co2_volume"
ATTR_BATCH_VOLUME = "batch_volume"